Skip to contents

This layout works to position nodes opposite their matching nodes. See manynet::to_matching() for more details on the matching procedure.

Usage

layout_matching(.data, center = NULL, circular = FALSE, times = 1)

layout_tbl_graph_matching(.data, center = NULL, circular = FALSE, times = 1)

Arguments

.data

Some {manynet} compatible network data.

center

Required for {ggraph} compatibility, and not used here.

circular

Should the layout be transformed into a radial representation. Only possible for some layouts. Defaults to FALSE. Required for {ggraph} compatibility.

times

Maximum number of iterations, where appropriate. Required for {ggraph} compatibility, and ignored by the layouts that do not iterate.

Value

Returns a table of nodes' x and y coordinates.