Learn R Programming

autograph (version 0.1.2)

map_motifs: Plotting tabular motifs

Description

These functions will plot graphs of the motifs used in a vector of results of e.g. a triad census.

Usage

# S3 method for node_motif
plot(x, ...)

# S3 method for network_motif plot(x, ...)

Value

plot.node_motif() returns a set of graphs that illustrate the motifs mentioned in the results from a node_motif function in {manynet}.

plot.network_motif() returns a set of graphs that illustrate the motifs mentioned in the results from a net_motif function in {manynet}.

Arguments

x

An object of "node_motif" class, e.g. resulting from a call to manynet::node_by_triad().

...

Other arguments to be passed on.