The "concentric" layout places the nodes on one or more circles, with each group of nodes on a circle of its own, and the groups ordered around those circles so that adjacent nodes are drawn close together. Where one group holds a single node, that node occupies the centre.
Usage
layout_concentric(
.data,
membership,
radius = NULL,
order.by = NULL,
circular = FALSE,
times = 1000
)
layout_tbl_graph_concentric(
.data,
membership,
radius = NULL,
order.by = NULL,
circular = FALSE,
times = 1000
)Source
Diego Diez, Andrew P. Hutchins and Diego Miranda-Saavedra. 2014. "Systematic identification of transcriptional regulatory modules from protein-protein interaction networks". Nucleic Acids Research, 42 (1) e6.
Arguments
- .data
Some
{manynet}compatible network data.- membership
A node attribute or a vector to draw concentric circles. By default this is the two modes of a two-mode network.
- radius
A vector of radii at which the concentric circles should be located. By default this is equal placement around an empty centre, unless one (the core) is a single node, in which case this node occupies the centre of the graph.
- order.by
An attribute label indicating the (decreasing) order for the nodes around the circles. By default ordering is given by a bipartite placement that reduces the number of edge crossings.
- circular
Should the layout be transformed into a radial representation. Only possible for some layouts. Defaults to FALSE. Required for
{ggraph}compatibility.- times
Maximum number of iterations, where appropriate. Required for
{ggraph}compatibility, and ignored by the layouts that do not iterate.